/***********************************************************
 *** Creating a file with data on concrete plants.        
 *** Also adding CBSA and population information to       
 ***   the data. Information appears in Tables 2 and 3.   
 ***  INPUT
 ***  mypanel.sas7bdat (made from longpanel.sas7bdat)
 ***  CBSAXwalk_names.csv (cross walks binding CBSA to county names)
 ***  construct.sas7bdat (County Business pattern)
 ***  OUTPUT
 ***  concrete.csv (for use in OCTAVE)
 ***----------------------------------------------------- 
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)         
 ***----------------------------------------------------- 
 *** This is a SAS9 file.                                 
 ***********************************************************/

options obs=max; 

libname cm 'd:\data\cm\' access=readonly;
*libname cm '/data/working/04/sasan/tfp/' access=readonly;
libname DATA '../data/';

*********selecting industries;
data DATA.concrete; 
   set cm.mypanel(where=(sic87=3273 and year in (1982,1987,1992,1997)));
   keep state county year q te wt ltfp sic87 age;
run; 

proc sort data=DATA.concrete;
   by state county;
run;

*********Reading CBSA Xwalk;
proc import datafile='../data/CBSAXwalk_names.csv' out=cbsa_xwalk
    dbms=csv replace;
run;

data cbsa_xwalk(keep=state county cbsa);
   set cbsa_xwalk;
   st=floor(fipsstco/1000);
   ct=fipsstco-1000*st;
   state = put(st,z2.);
   county = put(ct,z3.);
run;

proc sort data=cbsa_xwalk;
   by state county;
run;

*****Adding CBSA's to concrete data;
data DATA.concrete(drop=cb_code);
   merge DATA.concrete(in=a) cbsa_xwalk(in=b rename=(cbsa=cb_code));
   by state county;
   if a;
   cbsa = put(cb_code,z5.);
run;

%macro fill;
%do i=1 %to 10;
data DATA.concrete; 
   set DATA.concrete;
   by state;
   cbsa_lag = lag(cbsa); 
   if cbsa=. and not first.state then cbsa = cbsa_lag;
run;
%end;
%mend fill;
%fill

proc sort data=DATA.concrete; *(drop=cbsa_lag);
  by cbsa year;
run;

*****Adding population of construction workers to concrete data;
data DATA.concrete;
   merge DATA.concrete(in=a) DATA.construct(in=b);
   by cbsa year;
   if a and b;
   if ltfp ne .;
run;


*************Taking out the fixed effects; 
proc glm data=DATA.concrete noprint; 
   class year; 
   model ltfp = year; 
   output out=temp residual=r_ltfp; 
   weight wt;
   quit; 
run;


*************re-adjusting mean;
proc means data=temp noprint; 
   by sic87; 
   output out=means(drop=_TYPE_ _FREQ_) mean(r_ltfp ltfp)=mrtfp mtfp; 
   weight wt; 
run;  

data DATA.concrete(drop=mtfp mrtfp ltfp r_ltfp); 
   merge temp means; 
   by sic87; 
   r_ltfp = r_ltfp-mrtfp+mtfp;
   tfp = exp(r_ltfp);
run;



***********Output information************;
proc contents data=DATA.concrete;
  title "Concrete file contents";
run;

proc univariate data=DATA.concrete vardef=wdf;
   var tfp te q;
   weight wt;
run;


**********Output to CSV************;
data temp(keep= wt emp tfp te q);
   set DATA.concrete;
run;

proc export data=temp outfile='../data/concrete.csv'
     dbms=csv replace;
run;
