/**********************************************************
 **** Comparing productivity-size relationship among     
 ****   different industries with different market       
 ****   structures.                                      
 **** Concrete, Coffee, Ice, Box                         
 ***---------------------------------------------------- 
 *** Paper: Markets and the Non-monotonic Relation ... CJE, 2012,45(1), 345-372.
 *** By Sasan Bakhtiari (s.bakhtiari@unsw.edu.au)        
 ***---------------------------------------------------- 
 *** This is a SAS9 file.                                
 **********************************************************/

libname DATA '../data/'; 


proc sort data=DATA.local out=temp;
   by sic87;
run;

************Summary statistics by industry******;
proc means data=temp mean std p10 p90 vardef=wdf;
  class sic87; 
  var te tfp; 
  title1 "Summary statistics about different industries"; 
  weight wt;
run; 

**********Average productivities later used for indexing;
proc means data=DATA.local noprint;
  by sic87;
  output out=means(drop=_TYPE_ _FREQ_) mean(tfp)=sic_tfp;
  weight wt;
run;

data temp;
   merge temp means;
   by sic87;
   log_tfp = log(tfp/sic_tfp);
run;



*----------------------------------------------------------------------;
options mprint;
%let npoly=4; **degree of tfp polinomial;


data limits;
  sic87=2095; minp=-1.2; maxp=2.4;
  output;
  sic87=2097; minp=-1.7; maxp=1.6;
  output;
  sic87=2653; minp=-1.2; maxp=.7;
  output;
  sic87=3273; minp=-3.5; maxp=2;
  output;
run;


******building score file;
data prods;
  do sic87=2095,2097,2653,3273;
    output;
  end;
run; 

data prods(drop=j minp maxp); 
  merge prods limits;
  by sic87;
  array p{&npoly}; 
  year=1992;
  do p1= minp to maxp by 0.02;
    do j=1 to &npoly;
     p{j}=p1**j;
    end;
    output;
  end;
run;



*--------file used for modeling;
data mypanel(drop=i); 
   set temp;
   array p{&npoly};
   do i=1 to &npoly;
      p{i}=log_tfp**i; 
   end;
   log_te=log(te);
run;
 

******Regression Model******; 
ods output ParameterEstimates=beta;
proc glm data=mypanel;
   by sic87;
   class year;
   model log_te = p1 p2 p3 p4 year / solution;
   weight wt;
   quit;
run;


proc transpose data=beta out=beta;
   by sic87;
run;

data beta(keep=sic87 col:);
   set beta;
   if _NAME_='Estimate';
run;


data plotfile;
   merge prods beta means;
   by sic87;
   te = exp(col1+col2*p1+col3*p2+col4*p3+col5*p4+col8);
   p = exp(p1); 
run;


data pl0 pl1 pl2 pl3;  
   set plotfile; 
   select (sic87);
     when (3273) output pl0; 
     when (2095) output pl1;
     when (2097) output pl2;
     when (2653) output pl3;
   end; 
   keep p te;
run; 


/****Adding correct cement data;
proc import datafile="./bell_tfp..csv" out=bell_tfp 
     dbms=csv replace;
run;
data pl0(keep=p te emp);
   set bell_tfp;
   te=exp(P_log_te);
   p=exp(p1);
run; 

proc means data=pl0 noprint;
   by emp;
   output out=scale(drop=_TYPE_ _FREQ_) max(te)=max_te;
run;
data scale;
   set scale;
   emp2=emp*emp;
run;
proc reg data=scale outest=temp noprint;
   model max_te = emp emp2;
run;
data scale(keep=scale);
   if _N_=1 then set temp(keep=Intercept emp emp2);
   set scale(keep=max_te);
   scale = (Intercept+16700*emp+16700*16700*emp2)/max_te;
   if _N_=2 then output;
run;    
data pl0(keep=p te);
   set pl0;
   if _N_=1 then set scale;
   te = te*scale;
   if emp=10000 then output;
run; 
***************************************;*/

data plotfile; 
  merge pl0(rename=(te=te0)) pl1(rename=(te=te1)) pl2(rename=(te=te2)) pl3(rename=(te=te3));
  by p;
run; 


filename bell "../plots/compbell_tfp.ps";
symbol1 interpol=join value=none line=33 color=black width=8;  
symbol2 interpol=join value=none line=1 color=black width=8;   
symbol3 interpol=join value=none line=21 color=black width=8;
legend1 label=(height=.8cm 'Industry') value=(height=.8cm 'Concrete' 'Ice' 'Paper Box') across=1 position=(top right inside);
legend2 label=(height=.8cm 'Industry') value=(haight=.8cm 'Concrete' 'Coffee') across=1 position=(top left inside);
axis1 label=(angle=90 "Employment") order=(0 to 120 by 40);
axis2 label=(angle=90 "Employment") order=(0 to 320 by 80);
axis3 label=("TFP") logbase=10 logstyle=expand;
goptions device=pslepsfc gsfname=bell gsfmode=replace ftitle=centx 
         ftext=centx rotate=portrait vsize=25cm hsize=30cm htext=3; 

proc gplot data=plotfile;  
   plot te0*p=1 te2*p=2 te3*p=3 
        / overlay legend=legend1 vaxis=axis1 haxis=axis3; 
   title; 
run;

filename bell2 "../plots/compcoffee_tfp.ps";
goptions gsfname=bell2; 
proc gplot data=plotfile;  
   plot te0*p=1 te1*p=2
        / overlay legend=legend2 vaxis=axis2 haxis=axis3; 
   title; 
run;

